@@ -1,4 +1,4 @@
 from .router import Router
 from .handlers import select_one, select_all, query
 
-__all__ = ['Router', 'select_one', 'select_all', 'query']
+__all__ = ["Router", "select_one", "select_all", "query"]
