@@ -13,28 +13,25 @@ class ResultType(Enum):
 
 # noinspection PyArgumentList
 def select_all(sql: str, params: Tuple[Any] = None, result_type: ResultType = ResultType.TUPLE):
-    with connections['tmmis'].cursor() as cursor:
+    with connections["tmmis"].cursor() as cursor:
         cursor.execute(sql, params)
         if result_type == ResultType.DICT:
             columns = [col[0] for col in cursor.description]
-            return [
-                dict(zip(columns, row))
-                for row in cursor.fetchall()
-            ]
+            return [dict(zip(columns, row)) for row in cursor.fetchall()]
         elif result_type == ResultType.NAMEDTUPLE:
             desc = cursor.description
-            result = namedtuple('Result', [col[0] for col in desc])
+            result = namedtuple("Result", [col[0] for col in desc])
             return [result(*row) for row in cursor.fetchall()]
         else:
             return cursor.fetchall()
 
 
 def select_one(sql: str, params: Tuple[Any] = None):
-    with connections['tmmis'].cursor() as cursor:
+    with connections["tmmis"].cursor() as cursor:
         cursor.execute(sql, params)
         return cursor.fetchone()
 
 
 def query(sql: str, params: Tuple[Any] = None):
-    with connections['tmmis'].cursor() as cursor:
+    with connections["tmmis"].cursor() as cursor:
         cursor.execute(sql, params)
